--
-- PostgreSQL database dump
--

SET client_encoding = 'UTF8';
SET client_min_messages = warning;

--
-- Name: attack_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS attack_ids
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS attack_ids OWNER TO nw_api;

--
-- Name: attack; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS attack (
    id integer DEFAULT nextval('attack_ids'::regclass) NOT NULL,
    timestamp timestamp with time zone NOT NULL,
    lm boolean NOT NULL,
    vhost text NOT NULL,
    ip text NOT NULL,
    rule_id integer DEFAULT 0,
    method text NOT NULL,
    url text,
    param text,
    other_headers text,
    ua text,
    referer text,
    cookie text,
    body bytea,
    mz text,
    description text,
    bt integer DEFAULT 0,
    request_id text,
    waf_id text,
    group_id text,
    blocked boolean,
    possible boolean,
    cc char(2) DEFAULT NULL
);

ALTER TABLE IF EXISTS attack OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS attack_idx ON attack USING btree (id);

--
-- Name: scan_report_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS scan_report_ids
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS scan_report_ids OWNER TO nw_api;

--
-- Name: scan_report; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS scan_report (
    id integer DEFAULT nextval('scan_report_ids'::regclass) NOT NULL,
    scan_date timestamp without time zone NOT NULL,
    mz text,
    content text,
    domain text NOT NULL,
    method text NOT NULL,
    param text,
    payload text,
    type text,
    url text,
    data text,
    waf_id text NOT NULL
);

ALTER TABLE IF EXISTS scan_report OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS scan_report_idx ON scan_report USING btree (id);

--
-- Name: ml; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS ml (
    waf_id text,
    ml_learning_progress text,
    vhost text
);

ALTER TABLE IF EXISTS ml OWNER TO nw_api;

--
-- Name: models; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS models (
    timestamp timestamp without time zone DEFAULT CURRENT_TIMESTAMP::timestamp without time zone,
    model bytea,
    waf_id text,
    vhost text,
    hash text
);

ALTER TABLE IF EXISTS models OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS models_idx ON models USING btree (waf_id, vhost);

--
-- Name: training; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS training (
    waf_id text,
    vhost text,
    duration integer,
    complete boolean DEFAULT false,
    progress integer
);

ALTER TABLE IF EXISTS training OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS training_idx ON training USING btree (waf_id, vhost);

--
-- Name: openapi_url_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS openapi_url_ids
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS openapi_url_ids OWNER TO nw_api;

--
-- Name: openapi_url; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS openapi_url (
    id integer DEFAULT nextval('openapi_url_ids'::regclass) NOT NULL,
    timestamp timestamp with time zone DEFAULT CURRENT_TIMESTAMP NOT NULL,
    waf_id text,
    url bytea
);

ALTER TABLE IF EXISTS openapi_url OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS openapi_url_idx ON openapi_url USING btree (waf_id);

--
-- Name: openapi_schemas_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS openapi_schemas_ids
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS openapi_schemas_ids OWNER TO nw_api;

--
-- Name: openapi_schemas; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS openapi_schemas (
    id integer DEFAULT nextval('openapi_schemas_ids'::regclass) NOT NULL,
    timestamp timestamp with time zone DEFAULT CURRENT_TIMESTAMP NOT NULL,
    waf_id text,
    name text,
    schema bytea
);

ALTER TABLE IF EXISTS openapi_schemas OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS openapi_schemas_idx ON openapi_schemas USING btree (waf_id, name);

--
-- Name: openapi_schema_paths_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS openapi_schema_paths_ids
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS openapi_schema_paths_ids OWNER TO nw_api;

--
-- Name: openapi_schema_paths; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS openapi_schema_paths (
    id integer DEFAULT nextval('openapi_schema_paths_ids'::regclass) NOT NULL,
    timestamp timestamp with time zone DEFAULT CURRENT_TIMESTAMP NOT NULL,
    waf_id text,
    url text,
    schema bytea,
    schema_name text
);

ALTER TABLE IF EXISTS openapi_schema_paths OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS openapi_schema_paths_idx ON openapi_schema_paths USING btree (waf_id, url, schema_name);

--
-- Name: openapi_exclude_paths_idx_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS openapi_exclude_paths_ids
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS openapi_exclude_paths_ids OWNER TO nw_api;

--
-- Name: openapi_exclude_paths; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS openapi_exclude_paths (
    id integer DEFAULT nextval('openapi_exclude_paths_ids'::regclass) NOT NULL,
    timestamp timestamp with time zone DEFAULT CURRENT_TIMESTAMP NOT NULL,
    waf_id text,
    exclude_paths bytea
);

ALTER TABLE IF EXISTS openapi_exclude_paths OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS openapi_exclude_paths_idx ON openapi_exclude_paths USING btree (id);

--
-- Name: mt_main_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS mt_main_ids
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS mt_main_ids OWNER TO nw_api;

--
-- Name: mt_main; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS mt_main (
    id integer DEFAULT nextval('mt_main_ids'::regclass) NOT NULL,
    bt bigint,
    timestamp text,
    request_id text NOT NULL,
    mz text,
    mz_origin text,
    ip text,
    vhost text,
    method text,
    uri text,
    args text,
    cookie text,
    other_headers text,
    ua text,
    referer text,
    body text,
    waf_id text,
    agent text NOT NULL,
    cc character varying(2)
);

ALTER TABLE IF EXISTS mt_main OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS mt_main_idx ON mt_main USING btree (id);

--
-- Name: mt_export_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS mt_export_ids
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS mt_export_ids OWNER TO nw_api;

--
-- Name: mt_export; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS mt_export (
    id integer DEFAULT nextval('mt_export_ids'::regclass) NOT NULL,
    bt bigint NOT NULL,
    timestamp text NOT NULL,
    request_id text NOT NULL,
    mz text NOT NULL,
    vhost text NOT NULL,
    method text NOT NULL,
    uri text NOT NULL,
    args text NOT NULL,
    cookie text NOT NULL,
    ua text NOT NULL,
    referer text NOT NULL,
    body text NOT NULL,
    other_headers text,
    waf_id text NOT NULL
);

ALTER TABLE IF EXISTS mt_export OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS mt_export_idx ON mt_export USING btree (id);

--
-- Name: dyn_sync_ban; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS dyn_sync_ban (
    waf_id text,
    key_id character varying(32)
);

ALTER TABLE IF EXISTS dyn_sync_ban OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS dyn_sync_ban_idx ON dyn_sync_ban USING btree (key_id);

--
-- Name: dyn_bl; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS dyn_bl (
    active boolean DEFAULT true,
    modify timestamp without time zone DEFAULT (CURRENT_TIMESTAMP)::timestamp without time zone,
    waf_id text,
    bl text
);

ALTER TABLE IF EXISTS dyn_bl OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS dyn_bl_idx ON dyn_bl USING btree (waf_id);

--
-- Name: dyn_wl_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS dyn_wl_ids
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS dyn_wl_ids OWNER TO nw_api;

--
-- Name: dyn_wl; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS dyn_wl (
    id integer DEFAULT nextval('dyn_wl_ids'::regclass),
    modify timestamp without time zone DEFAULT (CURRENT_TIMESTAMP)::timestamp without time zone,
    active boolean DEFAULT true,
    waf_id text,
    domain text,
    mz text,
    extension text,
    rl_id text
);

ALTER TABLE IF EXISTS dyn_wl OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS dyn_wl_idx ON dyn_wl USING btree (id);

--
-- Name: dyn_wl_ts; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS dyn_wl_ts (
    modify timestamp without time zone DEFAULT (CURRENT_TIMESTAMP)::timestamp without time zone,
    waf_id text
);

ALTER TABLE IF EXISTS dyn_wl_ts OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS dyn_wl_ts_idx ON dyn_wl_ts USING btree (waf_id);

--
-- Name: dyn_erl_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS dyn_erl_ids
    START WITH 100000
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS dyn_erl_ids OWNER TO nw_api;

--
-- Name: dyn_erl; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS dyn_erl (
    id integer DEFAULT nextval('dyn_erl_ids'::regclass) NOT NULL,
    modify timestamp without time zone DEFAULT (CURRENT_TIMESTAMP)::timestamp without time zone,
    active boolean DEFAULT true,
    waf_id text,
    ip text,
    lm boolean DEFAULT false,
    api boolean DEFAULT true,
    noban boolean DEFAULT false,
    country text,
    domain text,
    url text,
    args text,
    body text,
    cookie text,
    ua text,
    referer text,
    other_headers text,
    no_cookie boolean DEFAULT false
);

ALTER TABLE IF EXISTS dyn_erl OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS dyn_erl_idx ON dyn_erl USING btree (id);

--
-- Name: dyn_erl_ts; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS dyn_erl_ts (
    modify timestamp without time zone DEFAULT (CURRENT_TIMESTAMP)::timestamp without time zone,
    waf_id text
);

ALTER TABLE IF EXISTS dyn_erl_ts OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS dyn_erl_ts_idx ON dyn_erl_ts USING btree (waf_id);

--
-- Name: dyn_settings; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS dyn_settings (
    active boolean DEFAULT true,
    modify timestamp without time zone DEFAULT (CURRENT_TIMESTAMP)::timestamp without time zone,
    wl text,
    rl text,
    nwaf_ai_extra_host_lm text,
    nwaf_ai_extra_host_wl text,
    nwaf_bf_detect_host_lm text,
    nwaf_b64_decode_disable text,
    nwaf_body_exclude text,
    nwaf_ddos_detect_host_lm text,
    nwaf_geoip_mla_disable text,
    nwaf_host_lm text,
    nwaf_host_wl text,
    nwaf_ip_lm text,
    nwaf_ip_wl text,
    nwaf_limit text,
    nwaf_mla_host_lm text,
    nwaf_put_body_exclude text,
    nwaf_rmq_host_exclude text,
    waf_id text,
    nwaf_url_wl text,
    nwaf_post_body_exclude text,
    nwaf_openapi_ip_wl text,
    nwaf_openapi_ip_lm text,
    nwaf_openapi_url_wl text,
    nwaf_openapi_url_lm text,
    nwaf_rfc_violation_wl text,
    nwaf_rfc_violation_lm text
);

ALTER TABLE IF EXISTS dyn_settings OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS dyn_settings_idx ON dyn_settings USING btree (waf_id);

--
-- Name: mlc_settings; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS mlc_settings (
    active boolean DEFAULT true,
    modify timestamp without time zone DEFAULT (CURRENT_TIMESTAMP)::timestamp without time zone,
    main__ai_extra boolean,
    ddos__enable boolean,
    ddos__wl_ip text,
    ddos__wl_url text,
    ddos__interval integer,
    ddos__latest_only boolean,
    ddos__send_possible boolean,
    brute__enable boolean,
    brute__brute_detect text,
    brute__flood_detect text,
    brute__wl_host text,
    brute__interval integer,
    brute__max_val integer,
    brute__latest_only boolean,
    brute__send_possible boolean,
    waf_id text,
    openapi__vhosts_list text
);

ALTER TABLE IF EXISTS mlc_settings OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS mlc_settings_idx ON mlc_settings USING btree (waf_id);

--
-- Name: vhosts_list; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS vhosts_list (
    vhosts_list text,
    waf_id text
);

ALTER TABLE IF EXISTS vhosts_list OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS vhosts_list_idx ON vhosts_list USING btree (waf_id);

--
-- Name: nginx_global; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS nginx_global (
    active boolean DEFAULT true,
    waf_id text,
    resolver text,
    resolver_timeout integer,
    set_real_ip_from text,
    real_ip_header text,
    client_max_body_size integer,
    limit_req_zone text
);

ALTER TABLE IF EXISTS nginx_global OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS nginx_global_idx ON nginx_global USING btree (waf_id);

--
-- Name: nginx_vhost; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS nginx_vhost (
    active boolean DEFAULT true,
    waf_id text NOT NULL,
    name text,
    listen text,
    server_name text,
    certificate_name text,
    dhparam_name text,
    ssl_session_timeout integer,
    ssl_ciphers text,
    ssl_protocols text,
    root text,
    index text,
    locations text
);

ALTER TABLE IF EXISTS nginx_vhost OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS nginx_vhost_idx ON nginx_vhost USING btree (waf_id, name);

--
-- Name: nginx_upstream; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS nginx_upstream (
    waf_id text NOT NULL,
    name text,
    balancing_method text,
    servers text
);

ALTER TABLE IF EXISTS nginx_upstream OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS nginx_upstream_idx ON nginx_upstream USING btree (waf_id, name);

--
-- Name: nginx_certificate; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS nginx_certificate (
    waf_id text NOT NULL,
    name text,
    certificate text,
    certificate_key text
);

ALTER TABLE IF EXISTS nginx_certificate OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS nginx_certificate_idx ON nginx_certificate USING btree (waf_id, name);

--
-- Name: nginx_dhparam; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS nginx_dhparam (
    waf_id text NOT NULL,
    name text,
    dhparam text
);

ALTER TABLE IF EXISTS nginx_dhparam OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS nginx_dhparam_idx ON nginx_dhparam USING btree (waf_id, name);

--
-- Name: events_ids; Type: SEQUENCE; Owner: nw_api
--

CREATE SEQUENCE IF NOT EXISTS events_ids
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;

ALTER TABLE IF EXISTS events_ids OWNER TO nw_api;

--
-- Name: events; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS events (
    id integer DEFAULT nextval('events_ids'::regclass) NOT NULL,
    waf_id text,
    timestamp integer,
    ip text,
    uuid text,
    level text,
    agent text,
    category text,
    description bytea
);

ALTER TABLE IF EXISTS events OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS events_idx ON events USING btree (id);

--
-- Name: geo_tokens; Type: TABLE; Owner: nw_api
--

CREATE TABLE IF NOT EXISTS geo_tokens (
    waf_id text,
    geo_token text
);

ALTER TABLE IF EXISTS geo_tokens OWNER TO nw_api;
CREATE UNIQUE INDEX IF NOT EXISTS geo_tokens_idx ON geo_tokens USING btree (waf_id, geo_token);

--
-- Name: DATABASE waf; Type: ACL; Owner: nw_api
--

GRANT ALL ON DATABASE waf TO nw_api;

--
-- PostgreSQL database dump complete
--