#!/usr/bin/env python3

import ipaddress
from core import log, base_api_uri, is_base64

##
# URLs
##

get_event_status_uri = base_api_uri + '/get_event_status'
set_event_uri = base_api_uri + '/set_event'
get_event_uri = base_api_uri + '/get_event'
del_event_uri = base_api_uri + '/del_event'

# Set event columns
set_event_cols = ['timestamp', 'ip', 'uuid', 'level', 'agent', 'category', 'description']

# Set the available values
agents = ['dyn', 'mla', 'mlc', 'cabinet', 'nws']
levels = ['debug', 'info', 'warn', 'error', 'fatal']

# Delete interval
event_eol = 60 * 60 * 24 * 90  # 90 days


def event_validation(k, v):
    try:

        if k == 'timestamp':
            if not isinstance(v, int):
                return False, 'The value {} of parameter {} is not an integer'.format(v, k)

        elif k == 'ip':
            if not isinstance(v, str):
                return False, 'The value {} of parameter {} is not an IP address'.format(v, k)
            try:
                ipaddress.ip_address(v)
            except Exception:
                return False, 'The value {} of parameter {} is not an IP address'.format(v, k)
            
        elif k == 'uuid' or k == 'category':
            if not isinstance(v, str):
                return False, 'The value {} of parameter {} is not a string'.format(v, k)
                
        elif k == 'level':
            if v not in levels:
                return False, 'The value {} of parameter {} is incorrect'.format(v, k)
            
        elif k == 'agent':
            if v not in agents:
                return False, 'The value {} of parameter {} is incorrect'.format(v, k)
            
        elif k == 'description':
            if not is_base64(v):
                return False, 'The value {} of parameter {} is not in Base64'.format(v, k)

    except Exception as e:
        err_msg = 'An error occurred during event validation: {}/{}: {}'.format(k, v, e)
        log.error(err_msg)
        return False, err_msg

    return True, ''
